@@ -24,7 +24,7 @@ var (
 )
 
 func gitHubLatestRelease(userRepo string) string {
-	user, repo, ok := chezmoi.CutString(userRepo, "/")
+	user, repo, ok := strings.Cut(userRepo, "/")
 	if !ok {
 		panic(fmt.Errorf("%s: not a user/repo", userRepo))
 	}
@@ -44,7 +44,7 @@ func gitHubLatestRelease(userRepo string) string {
 func run() error {
 	flag.Parse()
 
-	var templateData interface{}
+	var templateData any
 	if *templateDataFilename != "" {
 		dataBytes, err := os.ReadFile(*templateDataFilename)
 		if err != nil {
