@@ -5,7 +5,6 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
-	"go/build"
 	"io/fs"
 	"net/http"
 	"net/http/httptest"
@@ -73,17 +72,6 @@ func TestScript(t *testing.T) {
 			"unix2dos":       cmdUNIX2DOS,
 		},
 		Condition: func(cond string) (bool, error) {
-			// FIXME remove the following statement when
-			// https://github.com/rogpeppe/go-internal/pull/150 is released.
-			if strings.HasPrefix(cond, "build:") {
-				tag := strings.TrimPrefix(cond, "build:")
-				for _, releaseTag := range build.Default.ReleaseTags {
-					if releaseTag == tag {
-						return true, nil
-					}
-				}
-				return false, nil
-			}
 			if result, valid := goosCondition(cond); valid {
 				return result, nil
 			}
@@ -582,7 +570,7 @@ func cmdUNIX2DOS(ts *testscript.TestScript, neg bool, args []string) {
 // goosCondition evaluates cond as a logical OR of GOARCHes or GOOSes enclosed
 // in parentheses, returning true if any of them match.
 func goosCondition(cond string) (result, valid bool) {
-	// Interpret the condition as a logical OR of terms in parantheses.
+	// Interpret the condition as a logical OR of terms in parentheses.
 	if !strings.HasPrefix(cond, "(") || !strings.HasSuffix(cond, ")") {
 		result = false
 		valid = false
@@ -666,6 +654,7 @@ func setup(env *testscript.Env) error {
 					`:loop`,
 					`IF EXIST %~s1\NUL (`,
 					`	copy /y NUL "%~1\.edited" >NUL`,
+					// FIXME recursively edit all files if in a directory
 					`) ELSE (`,
 					`	echo # edited >> "%~1"`,
 					`)`,
@@ -677,8 +666,7 @@ func setup(env *testscript.Env) error {
 	default:
 		root["/bin"] = map[string]any{
 			// editor is a non-interactive script that appends "# edited\n" to
-			// the end of each file and creates an empty .edited file in each
-			// directory.
+			// the end of each file.
 			"editor": &vfst.File{
 				Perm: 0o755,
 				Contents: []byte(chezmoitest.JoinLines(
@@ -687,6 +675,9 @@ func setup(env *testscript.Env) error {
 					`for name in $*; do`,
 					`    if [ -d $name ]; then`,
 					`        touch $name/.edited`,
+					`        for filename in $(find $name -type f); do`,
+					`            echo "# edited" >> $filename`,
+					`        done`,
 					`    else`,
 					`        echo "# edited" >> $name`,
 					`    fi`,
