@@ -30,15 +30,41 @@ type ioregData struct {
 	value map[string]any
 }
 
-var (
-	// needsQuoteRx matches any string that contains non-printable characters,
-	// double quotes, or a backslash.
-	needsQuoteRx  = regexp.MustCompile(`[^\x21\x23-\x5b\x5d-\x7e]`)
-	startOfLineRx = regexp.MustCompile(`(?m)^`)
-)
+// needsQuoteRx matches any string that contains non-printable characters,
+// double quotes, or a backslash.
+var needsQuoteRx = regexp.MustCompile(`[^\x21\x23-\x5b\x5d-\x7e]`)
 
 func (c *Config) commentTemplateFunc(prefix, s string) string {
-	return startOfLineRx.ReplaceAllString(s, prefix)
+	type stateType int
+	const (
+		startOfLine stateType = iota
+		inLine
+	)
+
+	state := startOfLine
+	var builder strings.Builder
+	for _, r := range s {
+		switch state {
+		case startOfLine:
+			if _, err := builder.WriteString(prefix); err != nil {
+				panic(err)
+			}
+			if _, err := builder.WriteRune(r); err != nil {
+				panic(err)
+			}
+			if r != '\n' {
+				state = inLine
+			}
+		case inLine:
+			if _, err := builder.WriteRune(r); err != nil {
+				panic(err)
+			}
+			if r == '\n' {
+				state = startOfLine
+			}
+		}
+	}
+	return builder.String()
 }
 
 func (c *Config) fromIniTemplateFunc(s string) map[string]any {
@@ -93,7 +119,8 @@ func (c *Config) globTemplateFunc(pattern string) []string {
 }
 
 func (c *Config) includeTemplateFunc(filename string) string {
-	contents, err := c.readFile(filename)
+	searchDirAbsPaths := []chezmoi.AbsPath{c.SourceDirAbsPath}
+	contents, err := c.readFile(filename, searchDirAbsPaths)
 	if err != nil {
 		panic(err)
 	}
@@ -111,7 +138,11 @@ func (c *Config) includeTemplateTemplateFunc(filename string, args ...any) strin
 		panic(fmt.Errorf("expected 0 or 1 arguments, got %d", len(args)))
 	}
 
-	contents, err := c.readFile(filename)
+	searchDirAbsPaths := []chezmoi.AbsPath{
+		c.SourceDirAbsPath.JoinString(chezmoi.TemplatesDirName),
+		c.SourceDirAbsPath,
+	}
+	contents, err := c.readFile(filename, searchDirAbsPaths)
 	if err != nil {
 		panic(err)
 	}
@@ -212,18 +243,24 @@ func (c *Config) quoteListTemplateFunc(list []any) []string {
 	return result
 }
 
-func (c *Config) readFile(filename string) ([]byte, error) {
-	var absPath chezmoi.AbsPath
+func (c *Config) readFile(filename string, searchDirAbsPaths []chezmoi.AbsPath) ([]byte, error) {
 	if filepath.IsAbs(filename) {
-		var err error
-		absPath, err = chezmoi.NewAbsPathFromExtPath(filename, c.homeDirAbsPath)
+		absPath, err := chezmoi.NewAbsPathFromExtPath(filename, c.homeDirAbsPath)
 		if err != nil {
 			return nil, err
 		}
-	} else {
-		absPath = c.SourceDirAbsPath.JoinString(filename)
+		return c.fileSystem.ReadFile(absPath.String())
 	}
-	return c.fileSystem.ReadFile(absPath.String())
+
+	var data []byte
+	var err error
+	for _, searchDir := range searchDirAbsPaths {
+		data, err = c.fileSystem.ReadFile(searchDir.JoinString(filename).String())
+		if !errors.Is(err, fs.ErrNotExist) {
+			return data, err
+		}
+	}
+	return data, err
 }
 
 func (c *Config) replaceAllRegexTemplateFunc(expr, repl, s string) string {
